@@ -4,6 +4,7 @@
 #' @template occ
 #' @import httr plyr
 #' @export
+#' 
 #' @param name (character) Full scientific name potentially with authorship (required)
 #' @param rank (character) The rank given as our rank enum. (optional)
 #' @param kingdom (character) If provided default matching will also try to match against this 
@@ -21,11 +22,13 @@
 #' @param strict (logical) If TRUE it (fuzzy) matches only the given name, but never a 
 #'    taxon in the upper classification (optional)
 #' @param verbose (logical) If TRUE show alternative matches considered which had been rejected.
+#' 
 #' @return A list for a single taxon with many slots (with \code{verbose=FALSE} - default), or a 
 #' list of length two, first element for the suggested taxon match, and a data.frame
 #' with alternative name suggestions resulting from fuzzy matching (with \code{verbose=TRUE}).
 #' @details If you don't get a match GBIF gives back a list of length 3 with slots synonym, 
 #' confidence, and matchType='NONE'.
+#' 
 #' @examples \dontrun{
 #' name_backbone(name='Helianthus annuus', kingdom='plants')
 #' name_backbone(name='Helianthus', rank='genus', kingdom='plants')
@@ -51,8 +54,8 @@ name_backbone <- function(name, rank=NULL, kingdom=NULL, phylum=NULL, class=NULL
   order=NULL, family=NULL, genus=NULL, strict=FALSE, verbose=FALSE, 
   start=NULL, limit=20, callopts=list())
 {
-  url = 'http://api.gbif.org/v0.9/species/match'
-  args <- compact(list(name=name, rank=rank, kingdom=kingdom, phylum=phylum, 
+  url = 'http://api.gbif.org/v1/species/match'
+  args <- rgbif_compact(list(name=name, rank=rank, kingdom=kingdom, phylum=phylum, 
                        class=class, order=order, family=family, genus=genus, 
                        strict=strict, verbose=verbose, offset=start, limit=limit))
   temp <- GET(url, query=args, callopts)
