@@ -14,19 +14,19 @@
 #' character strings.
 #' @examples \dontrun{
 #' # catalog number
-#' occ_metadata(type = "catalog_number", q=122)
+#' occ_metadata(type = "catalogNumber", q=122)
 #' 
 #' # collection code
-#' occ_metadata(type = "collection_code", q=12)
+#' occ_metadata(type = "collectionCode", q=12)
 #' 
 #' # institution code
-#' occ_metadata(type = "institution_code", q='GB')
+#' occ_metadata(type = "institutionCode", q='GB')
 #' 
 #' # data as character strings
-#' occ_metadata(type = "catalog_number", q=122, pretty=FALSE)
+#' occ_metadata(type = "catalogNumber", q=122, pretty=FALSE)
 #' 
 #' # Change number of results returned
-#' occ_metadata(type = "catalog_number", q=122, limit=10)
+#' occ_metadata(type = "catalogNumber", q=122, limit=10)
 #' 
 #' # Partial unique type strings work too
 #' occ_metadata(type = "cat", q=122)
@@ -37,13 +37,13 @@
 #' occ_metadata(type = "collector_name", q='jane')
 #' }
 
-occ_metadata <- function(type = "catalog_number", q=NULL, limit=5, 
+occ_metadata <- function(type = "catalogNumber", q=NULL, limit=5, 
                          callopts=list(), pretty=TRUE)
 {
-  type <- match.arg(type, choices=c("catalog_number","collection_code",
-                                    "collector_name","institution_code"))
-  url <- sprintf('http://api.gbif.org/v0.9/occurrence/search/%s', type)
-  args <- compact(list(q = q, limit = limit))
+  type <- match.arg(type, choices=c("catalogNumber","collectionCode",
+                                    "collectorName","institutionCode"))
+  url <- sprintf('http://api.gbif.org/v1/occurrence/search/%s', type)
+  args <- rgbif_compact(list(q = q, limit = limit))
   tt <- GET(url, query=args, callopts)
   stop_for_status(tt)
   assert_that(tt$headers$`content-type`=='application/json')
