@@ -4,12 +4,15 @@
 #' @template occ
 #' @import httr
 #' @import plyr 
+#' @export
+#' 
 #' @param data The type of data to get. Default is all data.
 #' @param uuid UUID of the data node provider. This must be specified if data
 #'    is anything other than 'all'.
 #' @param query Query nodes. Only used when data='all'
+#' 
 #' @return A list.
-#' @export
+#' 
 #' @examples \dontrun{
 #' organizations()
 #' organizations(query="france")
@@ -21,10 +24,10 @@
 organizations <- function(data = 'all', uuid = NULL, query = NULL, limit=20, 
                           start=NULL, callopts=list())
 {
-  args <- compact(list(q = query, limit=as.integer(limit), offset=start))
+  args <- rgbif_compact(list(q = query, limit=as.integer(limit), offset=start))
   
   data <- match.arg(data, choices=c('all', 'organization', 'contact', 'endpoint', 
-                                    'identifier', 'tag', 'machinetag', 'comment', 
+                                    'identifier', 'tag', 'machineTag', 'comment', 
                                     'hostedDataset', 'ownedDataset', 'deleted', 
                                     'pending', 'nonPublishing'))
   
@@ -36,18 +39,18 @@ organizations <- function(data = 'all', uuid = NULL, query = NULL, limit=20,
     
     if(is.null(uuid)){
       if(x=='all'){
-        url <- 'http://api.gbif.org/v0.9/organization'
+        url <- 'http://api.gbif.org/v1/organization'
       } else
       {
-        url <- sprintf('http://api.gbif.org/v0.9/organization/%s', x)
+        url <- sprintf('http://api.gbif.org/v1/organization/%s', x)
       }
     } else
     {
       if(x=='all'){
-        url <- sprintf('http://api.gbif.org/v0.9/organization/%s', uuid)
+        url <- sprintf('http://api.gbif.org/v1/organization/%s', uuid)
       } else
       {
-        url <- sprintf('http://api.gbif.org/v0.9/organization/%s/%s', uuid, x)        
+        url <- sprintf('http://api.gbif.org/v1/organization/%s/%s', uuid, x)        
       }
     }
     temp <- GET(url, query=args, callopts)
