@@ -17,7 +17,7 @@
 #'              'Vanessa atalanta (Linnaeus, 1758)'))
 #' }
 parsenames <- function(scientificname) {
-  url <- "http://api.gbif.org/v0.9/parser/name"
+  url <- "http://api.gbif.org/v1/parser/name"
   tt <- POST(url,
              config=c(add_headers('Content-Type' = 
                                     'application/json')),
