@@ -12,8 +12,8 @@ test_that("type query returns the correct class", {
 tt <- dataset_suggest(query="amsterdam")
 test_that("search query returns the correct class", {
   expect_is(tt, "data.frame")
-  expect_is(tt$hostingOrganization, "character")
-  expect_is(tt$hostingOrganization[[1]], "character")
+  expect_is(tt$title, "character")
+  expect_is(tt$title[[1]], "character")
 })
 
 # Limited search
@@ -22,9 +22,6 @@ test_that("limited search returns the correct class", {
   expect_is(tt, "data.frame")
   expect_is(tt[1,1], "character")
 })
-test_that("limited search returns the correct dims", {
-  expect_equal(dim(tt), c(2,8))
-})
 
 # Return just descriptions
 tt <- dataset_suggest(type="OCCURRENCE", description=TRUE)
