@@ -11,7 +11,7 @@ test_that("name_suggest returns the correct class", {
   expect_is(c, "data.frame")
   expect_is(d, "data.frame")
   expect_is(a$key, "numeric")
-  expect_is(c$scientificName, "character")
+  expect_is(c$canonicalName, "character")
   expect_is(d$canonicalName, "character")
 })
 
@@ -25,6 +25,6 @@ test_that("name_suggest returns the correct dimensions", {
 
 test_that("name_suggest returns the correct value", {
   expect_equal(a$key[[1]], 2435099)
-  expect_equal(as.character(b$scientificName[[1]]), "Puma Jardine, 1834")
+  expect_equal(as.character(b$canonicalName[[1]]), "Puma")
   expect_equal(as.character(c$rank[[1]]), "GENUS")
 })
\ No newline at end of file
